@@ -24,6 +24,12 @@ pub type Result<T, E = Error> = std::result::Result<T, E>;
 #[derive(Debug, Error)]
 #[allow(missing_docs)]
 pub enum Error {
+    #[error("Max amount of service commands being handled, dropping command.")]
+    AtMaxServiceCommandThroughput,
+    #[error("Permit was not retrieved in 500 loops")]
+    CouldNotGetPermitInTime,
+    #[error("Node prioritisation semaphore was closed early.")]
+    SemaphoreClosed,
     #[error("Only messages requiring auth accumulation should be sent via \"send_messages_to_all_nodes_or_directly_handle_for_accumulation\"")]
     SendOrHandlingNormalMsg,
     #[error("There was a problem during acquisition of a tokio::sync::semaphore permit.")]
@@ -68,6 +74,10 @@ pub enum Error {
     TryJoinLater,
     #[error("No matching Section")]
     NoMatchingSection,
+    #[error(
+        "A JoinResponse was reeived after we've already joined the network. It has been ignored."
+    )]
+    AlreadyJoinedTheNetwork,
     #[error("No matching Elder")]
     NoMatchingElder,
     #[error("Node cannot join the network since it is not externally reachable: {0}")]
